# Standard library imports
import sys

# imports
import webuipy
from webuipy import viewer


def main():  # type: () -> None
    """show website"""
    args = [a for a in sys.argv[1:] if not a.startswith("-")]
    opts = [o for o in sys.argv[1:] if o.startswith("-")]

    # Show help message
    if "-h" in opts or "--help" in opts:
        viewer.show(__doc__)
        return

    # Get URL from config file
    url = webuipy.URL

    # Show website message
    if "-w" in opts or "--website" in opts:
        viewer.show(url)
        return

    if args:
        for arg in args:
            if arg == 'init':
                viewer.show('Setup initialization')
            else:
                viewer.show('Invalid Argument')

    # No ID is given, show list of articles
    else:
        viewer.show('hello, try to use init, -h or -w')


if __name__ == "__main__":
    main()



"""DataBamboo CLI Tool
"""
import importlib_resources as _resources
try:
    from configparser import ConfigParser as _ConfigParser
except ImportError:  # Python 2
    from ConfigParser import ConfigParser as _ConfigParser

__version__ = "0.0.1"

# Read URL from config file
_cfg = _ConfigParser()
with _resources.path("webuipy", "config.cfg") as _path:
    _cfg.read(str(_path))
URL = _cfg.get("website", "url")



"""Setup script for webuipy"""

import os.path
from setuptools import setup

# file directory
HERE = os.path.abspath(os.path.dirname(__file__))

# README file
with open(os.path.join(HERE, "README.md")) as fid:
    README = fid.read()

# setup everything
setup(
    name="webuipy",
    version="0.0.1",
    description="Python API Client for A1111 WebUI",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/datamonet",
    author="DataMonet LLC",
    author_email="support@replicable.art",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
    ],
    packages=["webuipy"],
    include_package_data=True,
    install_requires=[
        "importlib_resources",
    ],
    entry_points={"console_scripts": ["webuipy=webuipy.__main__:main"]},

)
